@@ -40,7 +40,7 @@ class BaseModel(nn.Module, ABC):
         try:
             ckpt_dict = torch.load(ckpt_file)
         except RuntimeError:
-            ckpt_dict = torch.load(ckpt_file, map_location='cuda:0')
+            ckpt_dict = torch.load(ckpt_file, map_location=lambda storage, loc: storage)
 
         # Restore model weights
         self.load_state_dict(ckpt_dict['model_state_dict'])
